@extends('layouts.auth')

@section('htmlheader_title')
	Log in
@endsection

@section('content')
	<svg xmlns="http://www.w3.org/2000/svg" style="display: none;">
		<symbol id="check-circle-fill" fill="currentColor" viewBox="0 0 16 16">
			<path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-3.97-3.03a.75.75 0 0 0-1.08.022L7.477 9.417 5.384 7.323a.75.75 0 0 0-1.06 1.06L6.97 11.03a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 0 0-.01-1.05z"/>
		</symbol>
		<symbol id="info-fill" fill="currentColor" viewBox="0 0 16 16">
			<path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm.93-9.412-1 4.705c-.07.34.029.533.304.533.194 0 .487-.07.686-.246l-.088.416c-.287.346-.92.598-1.465.598-.703 0-1.002-.422-.808-1.319l.738-3.468c.064-.293.006-.399-.287-.47l-.451-.081.082-.381 2.29-.287zM8 5.5a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>
		</symbol>
		<symbol id="exclamation-triangle-fill" fill="currentColor" viewBox="0 0 16 16">
			<path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>
		</symbol>
	</svg>

	@if(isset($login_note) AND $login_note)
		<div class="row">
			<div class="col-8 m-auto">
				<div class="alert alert-info alert-dismissible" role="alert">
					<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
					<h4 class="alert-heading">
						<svg class="bi flex-shrink-0 me-2" width="24" height="24" role="img" aria-label="Info:"><use xlink:href="#info-fill"/></svg>
						NOTE!
					</h4>
					{!! $login_note !!}
				</div>
			</div>
		</div>
	@endisset

	@if (Session::has('error'))
		<div class="row">
			<div class="col-8 m-auto">
				<div class="alert alert-danger alert-dismissible" role="alert">
					<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
					<h4 class="alert-heading">
						<svg class="bi flex-shrink-0 me-2" width="24" height="24" role="img" aria-label="Danger:"><use xlink:href="#exclamation-triangle-fill"/></svg>
						<strong>Whoops!</strong> Some is not right...
					</h4>
					{{ Session::get('error') }}</li>
				</div>
			</div>
		</div>
	@endif

	@if (count($errors) > 0)
		<div class="row">
			<div class="col-8 m-auto">
				<div class="alert alert-danger" role="alert">
					<h4 class="alert-heading">
						<svg class="bi flex-shrink-0 me-2" width="24" height="24" role="img" aria-label="Danger:"><use xlink:href="#exclamation-triangle-fill"/></svg>
						<strong>Whoops!</strong> Some is not right...
					</h4>
					<ul>
						@foreach ($errors->all() as $error)
							<li>{{ $error }}</li>
						@endforeach
					</ul>
				</div>
			</div>
		</div>
	@endif

	<div class="row">
		<div class="col-6 m-auto">
			<div class="greyframe titledbox shadow0xb0 text-center">
				<h2 class="cap">Login</h2>

				<form class="row g-0 needs-validation" method="post" novalidate>
					{{ csrf_field() }}

					<div class="row">
						<div class="col-12">
							<label for="email" class="form-label">Email</label>
							<div class="input-group has-validation">
								<span class="input-group-text"><i class="bi bi-person-badge"></i></span>
								<input type="text" class="form-control" id="email" placeholder="Email" name="email" required>
								<div class="invalid-feedback">
									Your email is required.
								</div>
							</div>
						</div>
					</div>

					<div class="row">
						<div class="col-12">
							<label for="password" class="form-label">Password</label>
							<div class="input-group has-validation">
								<span class="input-group-text"><i class="bi bi-key-fill"></i></span>
								<input type="password" class="form-control" id="password" placeholder="Password" name="password" required>
								<div class="invalid-feedback">
									Your password is required.
								</div>
							</div>
						</div>
					</div>

					<div class="row">
						<div class="col-4">
							<label><input type="checkbox" name="remember"> Remember Me</label>
						</div>
					</div>

					<div class="row">
						<div class="col-12">
							<a href="{{ url('/') }}" class="btn btn-danger">Cancel</a>
							<button type="submit" name="submit" class="btn btn-success mr-0 float-end">Sign In</button>
						</div>
					</div>
				</form>

				<div class="row pt-4">
					<div class="col-12">
						<a class="link-danger" href="{{ url('password/reset') }}">Forgot Password</a>
					</div>
				</div>

				<div class="row pt-1 pb-3">
					<div class="col-12">
						<a class="link-danger" href="{{ url('register') }}">Register</a>
					</div>
				</div>
			</div>
		</div>
	</div>
@endsection